@@ -91,6 +91,7 @@ class ColorDetectionConfig(BaseConfig):
         }
     }
 )
+    true_import: bool = False
 
     def validate(self) -> List[str]:
         errors = super().validate()
@@ -157,11 +158,7 @@ class ColorDetectionUseCase(BaseProcessor):
         self._zone_current_counts = {}  # zone_name -> current count in zone
         self._zone_total_counts = {}  # zone_name -> total count that have been in zone
         self.logger.info("Initialized ColorDetectionUseCase with zone tracking")
-        try:
-            self.detector = ClipProcessor()
-        except Exception as e:
-            self.logger.error(f"Error initializing ClipProcessor: {e}")
-            self.detector = None
+        self.detector = None #ClipProcessor()
         self.all_color_data = {}
         self.all_color_counts = {}
         #self.jpeg = TurboJPEG()
@@ -185,6 +182,10 @@ class ColorDetectionUseCase(BaseProcessor):
                     context=context
                 )
             
+            if config.true_import and self.detector is None:
+                self.detector = ClipProcessor()
+                self.logger.info("Initialized ClipProcessor for color detection")
+
             if context is None:
                 context = ProcessingContext()
             
